<?php
/** Turoyo (Ṫuroyo)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Ariyo
 */

$messages = array(
# User preference toggles
'tog-oldsig' => 'Imḍa du3do:',

'underline-always' => 'Kulnaqa',
'underline-never' => 'Hiç',

# Dates
'sunday' => 'Yawme dḤuşabo',
'monday' => 'Yawme dTre',
'tuesday' => 'Yawme dTloṭo',
'wednesday' => 'Yawme dArb³o',
'thursday' => 'Yawme dḤamşo',
'friday' => 'Yawme d3rufto',
'saturday' => 'Yawme dŞabṭo',
'sun' => 'Yawme dḤuşabo',
'mon' => 'Yawme dTre',
'tue' => 'Yawme dTloṭo',
'wed' => 'Yawme dArb³o',
'thu' => 'Yawme dḤamşo',
'fri' => 'Yawme d3rufto',
'sat' => 'Yawme dŞabṭo',
'january' => 'Konun ḥroy',
'february' => 'Şboṫ',
'march' => 'Oḍor',
'april' => 'Nison',
'may_long' => 'İyor',
'june' => 'Ḥziron',
'july' => 'Tamuz',
'august' => 'Ob',
'september' => 'Eylül',
'october' => 'Teşrin qḍim',
'november' => 'Teşrin ḥroy',
'december' => 'Konun qḍim',
'january-gen' => 'Konun ḥroy',
'february-gen' => 'Şboṫ',
'march-gen' => 'Oḍor',
'april-gen' => 'Nison',
'may-gen' => 'İyor',
'june-gen' => 'Ḥziron',
'july-gen' => 'Tamuz',
'august-gen' => 'Ob',
'september-gen' => 'Eylül',
'october-gen' => 'Teşrin qḍim',
'november-gen' => 'Teşrin ḥroy',
'december-gen' => 'Konun qḍim',
'jan' => 'Konun II',
'feb' => 'Şboṫ',
'mar' => 'Oḍor',
'apr' => 'Nison',
'may' => 'İyor',
'jun' => 'Ḥziron',
'jul' => 'Tamuz',
'aug' => 'Ob',
'sep' => 'Eylül',
'oct' => 'Teşrin I',
'nov' => 'Teşrin II',
'dec' => 'Konun I',

# Categories related messages
'pagecategories' => '{{PLURAL:$1|Sedro|Sedre}}',
'category_header' => 'Faṭoṭe bu Sedro "$1"',
'subcategories' => 'Sedre na³ime',
'category-media-header' => 'Mediya buSedro "$1"',
'category-empty' => 'U³do layto Faṭo aw Mediya buSedrano.',
'hidden-categories' => '{{PLURAL:$1|Hidden category|Hidden categories}}',
'category-subcat-count' => '{{PLURAL:$2|This category has only the following subcategory.|This category has the following {{PLURAL:$1|subcategory|$1 subcategories}}, out of $2 total.}}',
'category-article-count' => '{{PLURAL:$2|This category contains only the following page.|The following {{PLURAL:$1|page is|$1 pages are}} in this category, out of $2 total.}}',
'category-file-count' => '{{PLURAL:$2|This category contains only the following file.|The following {{PLURAL:$1|file is|$1 files are}} in this category, out of $2 total.}}',
'listingcontinuesabbrev' => 'mdawam',
'noindex-category' => 'Noindexed pages',

'about' => '3al',
'newwindow' => '(gmıftaḥ bKawṭo ḥaṭto)',
'cancel' => 'Mbaṫel',
'moredotdotdot' => 'Heşa...',
'mypage' => 'iFaṭayḍi',
'mytalk' => 'uMamlayḍi',
'navigation' => 'Navigasyon',
'and' => '&#32;u',

# Cologne Blue skin
'qbfind' => 'Ḥzay',
'qbbrowse' => 'Krax',
'qbedit' => 'Mşaḥlaf',
'qbpageoptions' => 'iFaṭaṭe',
'qbmyoptions' => 'aFaṭoṭayḍi',
'qbspecialpages' => 'Faṭoṭe dilonoye',
'faq' => 'Şuwole',
'faqpage' => 'Project:FAQ',

# Vector skin
'vector-action-addsection' => 'Maḥat Fusoqo ḥaṭo',
'vector-action-delete' => 'Slag',
'vector-action-move' => 'Mtaxar',
'vector-action-protect' => 'Mastar',
'vector-view-create' => 'Xlaq',
'vector-view-edit' => 'Mşaḥlaf',
'vector-view-history' => 'Maktabzabno',
'vector-view-view' => 'Qray',
'vector-view-viewsource' => 'Maḥway li aMabu³e.',
'actions' => 'Dubore',
'namespaces' => 'Dukṭo luIşmo',
'variants' => 'Variants',

'errorpagetitle' => 'Fawdo',
'returnto' => 'D³ar l$1',
'tagline' => 'men {{SITENAME}}',
'help' => '3udrono',
'search' => 'krax',
'searchbutton' => 'Krax',
'go' => 'Zux',
'searcharticle' => 'Zux',
'history' => 'Maktabzabno diFaṭo',
'history_short' => 'Maktabzabno',
'updatedmarker' => 'aŞuḥlofe datsimi miNaqa du3boroayḍi ḥaroyo',
'printableversion' => 'Printable version',
'permalink' => 'Asiruṭo aminoyto',
'print' => 'Ṫba³',
'view' => 'Qray',
'edit' => 'Mşaḥlaf',
'create' => 'Xlaq',
'editthispage' => 'Mşaḥlaf iFaṭaṭe',
'create-this-page' => 'Xlaq iFaṭaṭe',
'delete' => 'Slag',
'deletethispage' => 'Slag iFaṭaṭe',
'protect' => 'Mastar',
'protect_change' => 'mşaḥlaf',
'protectthispage' => 'Mastar iFaṭaṭe',
'newpage' => 'Faṭo ḥaṭto',
'talkpage' => 'Sım Droşo 3al iFaṭaṭe',
'talkpagelinktext' => 'Mamlo',
'specialpage' => 'Faṭo dilonoyto',
'personaltools' => 'aMonayḍi',
'postcomment' => 'Fusoqo ḥaṭo',
'articlepage' => 'Ḥur baḤbişoṭo',
'talk' => 'Droşo',
'views' => 'Ḥzayoṭo',
'toolbox' => 'Mone',
'viewtalkpage' => 'Ḥur buDroşo',
'otherlanguages' => 'bLeşone ḥrene',
'redirectedfrom' => '(Redirected from $1)',
'lastmodifiedat' => 'uŞuḥlofo ḥaroyo diFaṭaṭe bu Zabnano wa:  $1 $2 .',
'jumpto' => 'Zux l',
'jumptonavigation' => 'Navigasyon',
'jumptosearch' => 'Kruxyo',
'pool-errorunknown' => 'Fawdo nuxroyo',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage).
'aboutsite' => '3al {{SITENAME}}',
'aboutpage' => 'Project: 3al',
'copyrightpage' => '{{ns:project}}:Ḥaqat duKaṭowo',
'currentevents' => 'Gedşe ḥaṭe',
'currentevents-url' => 'Project:Gedşe du³do',
'disclaimers' => 'Disclaimers',
'disclaimerpage' => 'Project: Disclaimer gawonoyo',
'edithelp' => 'Editing help',
'helppage' => 'Help: Ḥbişoṭo',
'mainpage' => 'Faṭo rişoyto',
'mainpage-description' => 'Faṭo rişoyto',
'portal' => 'Portal diJama³a',
'portal-url' => 'Project: Portal diJama³a',
'privacy' => 'Setoro daMawd³onwoṭo',
'privacypage' => 'Project: Setoro daMawd³onwoṭo',

'badaccess-group0' => 'Hat latlux uFsoso dkolozım dsaymat iḤarakaṭe.',

'ok' => 'Tamam',
'retrievedfrom' => 'men "$1"',
'youhavenewmessages' => 'Kıtlux $1 ($2) .',
'newmessageslink' => 'Ṫebe ḥaṭe',
'newmessagesdifflink' => 'Degoşo ḥaroyo',
'youhavenewmessagesmulti' => 'Kitlux Ṫebe ḥaṭe b$1',
'editsection' => 'mşaḥlaf',
'editold' => 'mşaḥlaf',
'viewsourceold' => 'Maḥway li uMabu³o.',
'editlink' => 'mşaḥlaf',
'viewsourcelink' => 'Maḥway li uMabu³o.',
'editsectionhint' => 'Mşaḥlaf uFusoqano: $1',
'toc' => 'Ḥbişoṭo',
'showtoc' => 'maḥway',
'hidetoc' => 'tlay',
'collapsible-collapse' => 'sxar',
'collapsible-expand' => 'ftaḥ',
'feedlinks' => 'Feed:',
'site-rss-feed' => '$1 RSS feed',
'site-atom-feed' => '$1 Atom feed',
'page-rss-feed' => '"$1" RSS feed',
'page-atom-feed' => 'Atom feed l"$1"',
'red-link-title' => '$1 (layto iFaṭaṭe)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Faṭo',
'nstab-user' => 'Faṭo duHadomo',
'nstab-media' => 'Faṭo diMediya',
'nstab-special' => 'Faṭo dilonoyto',
'nstab-project' => 'Faṭo diProja',
'nstab-image' => 'Fayl',
'nstab-mediawiki' => 'Ṫebo',
'nstab-template' => 'Template',
'nstab-help' => 'Faṭo d3udrono',
'nstab-category' => 'Sedro',

# General errors
'error' => 'Fawdo',
'missing-article' => 'uSyomo d$1 $2 lo komaḥwe biDatabase.

iFaṭaṭe belki sligo aw mtaxro merke.

Elo iḍa dlo howe hawxa belki ḥselux Fawdo biSoftware. Bo³o haw Ṫebo l[[Special:ListUsers/sysop|Administrator]] u kṭaw u"URL".',
'missingarticle-rev' => '(Numara duVersyon: $1)',
'badtitle' => 'Bad title',
'badtitletext' => 'The requested page title was invalid, empty, or an incorrectly linked inter-language or inter-wiki title.
It may contain one or more characters which cannot be used in titles.',
'viewsource' => 'Maḥway li aMabu³e.',
'namespaceprotected' => "Hat latlux Ḥaq dımşaḥılfat Faṭoṭe bi'''$1''' Dukṭo xliṭo.",

# Virus scanner
'virus-unknownscanner' => 'Antivirus nuxroyo:',

# Login and logout pages
'yourname' => 'Işme duHadomo:',
'yourpassword' => 'Qliḍo:',
'yourpasswordagain' => 'Naqla ḥreto kṭaw uQliḍo:',
'remembermypassword' => 'Dxar uQliḍayḍi buBrowser (buSowudo $1 {{PLURAL:$1|Yawmo|Yawme}})',
'login' => '3bar',
'nav-login-createaccount' => '3bar / Hway Hadomo',
'loginprompt' => 'Glozım maqablat Cookies qanna dqudrat fıtḥat {{SITENAME}}.',
'userlogin' => '3bar / Hway Hadomo',
'userloginnocreate' => '3bar',
'logout' => 'Nfoqo',
'userlogout' => 'Nfoqo',
'notloggedin' => 'Heş lo3abirat.',
'nologin' => 'Heş lawit Hadomo? $1',
'nologinlink' => 'Hway Hadomo',
'createaccount' => 'Hway Hadomo',
'gotaccount' => 'Ma hawit ste Hadomo? $1',
'gotaccountlink' => '3bar',
'userlogin-resetlink' => 'Ṫa³at uQliḍayḍox?',
'createaccountmail' => 'buEmail',
'wrongpassword' => 'uQliḍayḍux fawdo yo.
Mjarab Naqla ḥreto.',
'wrongpasswordempty' => 'Lo msta³melux uQliḍayḍux.
Mjarab Naqla ḥreto.',
'password-name-match' => 'Glozım towe Frişuṭo beyn uQliḍo u uIşmayḍux.',
'mailmypassword' => 'Mşadar li Qliḍo ḥaṭo',
'loginlanguagelabel' => 'Leşono: $1',

# Change password dialog
'resetpass' => 'Mşaḥlaf uQliḍo.',
'oldpassword' => 'Qliḍo 3atiqo:',
'newpassword' => 'Qliḍo ḥaṭo:',
'retypenew' => 'Qliḍo ḥaṭo (disa):',
'resetpass-submit-loggedin' => 'Mşaḥlaf uQliḍo',

# Special:PasswordReset
'passwordreset-username' => 'Işme duHadomo:',

# Special:ChangeEmail
'changeemail-newemail' => 'Email-adres ḥaṭo:',

# Edit page toolbar
'bold_sample' => 'Ḥarfe ḥlime',
'bold_tip' => 'Ḥarfe ḥlime',
'italic_sample' => 'Ḥarfe 3wije',
'italic_tip' => 'Ḥarfe 3wije',
'link_sample' => 'Link title',
'link_tip' => 'Internal link',
'extlink_sample' => 'http://www.example.com link title',
'extlink_tip' => 'External link (remember http:// prefix)',
'headline_sample' => 'Headline text',
'headline_tip' => 'Level 2 headline',
'nowiki_sample' => 'Insert non-formatted text here',
'nowiki_tip' => 'uSyomano latyo buFormat',
'image_tip' => 'Embedded file',
'media_tip' => 'File link',
'sig_tip' => 'Mḍay herke u kṭaw iSa³aye muqa yo.',
'hr_tip' => 'Horizontal line (use sparingly)',

# Edit pages
'summary' => 'Summary:',
'minoredit' => 'This is a minor edit',
'watchthis' => 'Watch this page',
'savearticle' => 'Mqayad iFaṭaṭe',
'preview' => 'Preview',
'showpreview' => 'Show preview',
'showdiff' => 'Maḥway aŞuḥlofe',
'anoneditwarning' => "'''Diqad''' Heş lo 3abirat.
uIP-Adresayḍux gmikṭaw buMaktabzabno diFaṭaṭe. Kul Noşo kibe ḥozele u lo komislag.",
'loginreqtitle' => 'Glozım 3obrat',
'loginreqlink' => '3bar',
'loginreqpagetext' => 'Glozım $1 qanna dqudrat ḥozat Faṭoṭe ḥrene.',
'newarticle' => '(Ḥaṭo)',
'newarticletext' => "You have followed a link to a page that does not exist yet.
To create the page, start typing in the box below (see the [[{{MediaWiki:Helppage}}|help page]] for more info).
If you are here by mistake, click your browser's '''back''' button.",
'noarticletext' => 'There is currently no text in this page.
You can [[Special:Search/{{PAGENAME}}|search for this page title]] in other pages,
<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} search the related logs],
or [{{fullurl:{{FULLPAGENAME}}|action=edit}} edit this page]</span>.',
'noarticletext-nopermission' => 'There is currently no text in this page.
You can [[Special:Search/{{PAGENAME}}|search for this page title]] in other pages,
or <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} search the related logs]</span>.',
'previewnote' => "'''Remember that this is only a preview.'''
Your changes have not yet been saved!",
'editing' => 'Şuḥlofo d$1',
'editingsection' => 'Mşaḥlaf $1 (Fusoqo)',
'yourtext' => 'uSyomayḍux',
'yourdiff' => 'Frişwoṭo',
'templatesused' => '{{PLURAL:$1|Template|Templates}} used on this page:',
'template-protected' => '(protected)',
'template-semiprotected' => '(semi-protected)',
'hiddencategories' => 'This page is a member of {{PLURAL:$1|1 hidden category|$1 hidden categories}}:',
'permissionserrorstext-withaction' => 'You do not have permission to $2, for the following {{PLURAL:$1|reason|reasons}}:',
'recreate-moveddeleted-warn' => "'''Warning: You are recreating a page that was previously deleted.'''

You should consider whether it is appropriate to continue editing this page.
The deletion and move log for this page are provided here for convenience:",
'moveddeleted-notice' => 'iFaṭaṭe sligto yo.
The deletion and move log for the page are provided below for reference.',

# Parser/template warnings
'post-expand-template-inclusion-warning' => "'''Warning:''' Template include size is too large.
Some templates will not be included.",
'post-expand-template-inclusion-category' => 'Pages where template include size is exceeded',
'post-expand-template-argument-warning' => "'''Warning:''' This page contains at least one template argument which has a too large expansion size.
These arguments have been omitted.",
'post-expand-template-argument-category' => 'Pages containing omitted template arguments',

# History pages
'viewpagelogs' => 'View logs for this page',
'currentrev-asof' => 'Latest revision as of $1',
'revisionasof' => 'Versyon 3atiqo diNaqa: $1',
'revision-info' => 'Revision as of $1 by $2',
'previousrevision' => '←Versyon 3atiqtır',
'nextrevision' => 'Versyon ḥaṭtır',
'currentrevisionlink' => 'Latest revision',
'cur' => 'du³do',
'next' => 'Ḥreto',
'last' => 'dmeqım',
'page_first' => 'Badaye',
'page_last' => 'Ḥarayto',
'histlegend' => "Diff selection: Mark the radio boxes of the revisions to compare and hit enter or the button at the bottom.<br />
Legend: '''({{int:cur}})''' = difference with latest revision, '''({{int:last}})''' = difference with preceding revision, '''{{int:minoreditletter}}''' = minor edit.",
'history-fieldset-title' => 'Krax buMaktabzabno',
'history-show-deleted' => 'Bes aSlige',
'histfirst' => 'Meqım kulle',
'histlast' => 'Ḥaṭo',
'historysize' => '({{PLURAL:$1|1 byte|$1 bytes}})',
'historyempty' => '(xalyo)',

# Revision feed
'history-feed-item-nocomment' => '$1  b$2',

# Revision deletion
'rev-delundel' => 'maḥway / tlay',
'rev-showdeleted' => 'maḥway',
'revdelete-show-file-submit' => 'Eh',
'revdelete-radio-same' => '(lo mşaḥalfat)',
'revdelete-radio-set' => 'Eh',
'revdelete-radio-unset' => 'Lo',
'revdel-restore' => 'change visibility',
'revdel-restore-deleted' => 'deleted revisions',
'revdel-restore-visible' => 'visible revisions',
'pagehist' => 'Maktabzabno diFaṭo',

# Merge log
'revertmerge' => 'Unmerge',

# Diffs
'history-title' => 'Revision history of "$1"',
'lineno' => 'Serṫo $1:',
'compareselectedversions' => 'Compare selected revisions',
'editundo' => 'slag',
'diff-multi' => '({{PLURAL:$1|One intermediate revision|$1 intermediate revisions}} by {{PLURAL:$2|one user|$2 users}} not shown)',

# Search results
'searchresults' => 'Nafqe duKruxyayḍux',
'searchresults-title' => 'Nafqe duKruxyo l"$1"',
'searchsubtitleinvalid' => "Karixat '''$1'''",
'prevn' => '{{PLURAL:$1|$1}} meqımtır',
'nextn' => '{{PLURAL:$1 ḥaṭtır| $1 ḥaṭtır }}',
'prevn-title' => '{{PLURAL:$1 Nafqo meqımtır|$1 Nafqe meqımtır}}',
'nextn-title' => '{{PLURAL:$1|Nafqo ḥreno|$1 Nafqe ḥrene}}',
'shown-title' => 'maḥway $1 {{PLURAL:$1|Nafqo|Nafqe}} bḥḍo Faṭo',
'viewprevnext' => 'Maḥway ($1 {{int:pipe-separator}} $2) ($3)',
'searchmenu-legend' => '3ayar duKruxyo',
'searchmenu-exists' => "'''Kito Faṭo herke Işma \"[[:\$1]]\"yo'''",
'searchmenu-new' => 'Kṭaw iFaṭaṭe "[[:$1]]" buWiki.',
'searchprofile-articles' => 'Faṭoṭe daḤbişoṭo',
'searchprofile-project' => 'Faṭoṭe du3udrono u daProjat',
'searchprofile-images' => 'Multimediya',
'searchprofile-everything' => 'Kulmede',
'searchprofile-advanced' => 'Advanced',
'searchprofile-articles-tooltip' => 'Krax b$1',
'searchprofile-project-tooltip' => 'Krax b$1',
'searchprofile-images-tooltip' => 'Krax Ṥurtoṭe',
'searchprofile-everything-tooltip' => 'Krax baḤbişoṭo (baFaṭoṭe duDroşo ste)',
'searchprofile-advanced-tooltip' => 'Search in custom namespaces',
'search-result-size' => '$1 ({{PLURAL:$2|1 Melṭo|$2 Mele}})',
'search-result-category-size' => '{{PLURAL:$1|1 Hadomo|$1 Hadome}} ({{PLURAL:$2|1 Sedro taḥtoyo|$2 Sedre taḥtoye}}, {{PLURAL:$3|1 file|$3 files}})',
'search-redirect' => '(Asiruṭo men $1)',
'search-section' => '(Fusoqo $1)',
'search-suggest' => 'Ub³atwa dkıṭwat: $1?',
'search-interwiki-more' => '(heşa)',
'searchrelated' => 'related',
'searchall' => 'kulle',
'showingresultsheader' => "{{PLURAL:$5|Nafqo '''$1''' of '''$3'''|Nafqe '''$1 - $2''' men '''$3'''}} l'''$4'''",
'search-nonefound' => 'Für deine Suchanfrage wurden keine Ergebnisse gefunden.',
'powersearch-field' => 'Krax',
'powersearch-togglelabel' => 'Sım Qontrol:',
'powersearch-toggleall' => 'Kulle',

# Preferences page
'preferences' => '3ayarat',
'mypreferences' => 'a3ayaratayḍi',
'prefs-edits' => 'Menyono daŞuḥlofe kulle:',
'prefs-resetpass' => 'Mşaḥlaf uQliḍo',
'prefs-email' => '3ayarat duEmail',
'saveprefs' => 'Mqayad',
'searchresultshead' => 'Kruxyo',
'timezoneregion-africa' => 'Afriqa',
'timezoneregion-america' => 'Ameriqa',
'timezoneregion-antarctica' => 'Antarctica',
'timezoneregion-arctic' => 'Arctic',
'timezoneregion-asia' => 'Asia',
'timezoneregion-atlantic' => 'Yamo atlantikoyo',
'timezoneregion-australia' => 'Australia',
'timezoneregion-europe' => 'Awrifi',
'timezoneregion-indian' => 'Yamo hindoyo',
'youremail' => 'Adres duEmail',
'username' => 'Işme duHadomo:',
'prefs-memberingroups' => 'Hadomo d{{PLURAL:$1|Gudo|Gudoṭo}}:',
'prefs-registration' => 'Zabno duSugolo:',
'yourrealname' => 'Işmo şariro:',
'yourlanguage' => 'Leşono',
'yournick' => 'Imḍa ḥaṭto:',
'yourgender' => 'Ğenso:',
'gender-male' => 'Dekronoyo',
'gender-female' => 'Neqıbṭonoyo',
'email' => 'Email',
'prefs-help-email' => 'Latat majbur dkıṭwat uEmail-Adresayḍox, elo glozam inaqla ṫo³at uQliḍayḍox u hakka dlozam dmişadar lox Qliḍo ḥaṭo.',
'prefs-help-email-others' => 'Kibux mijğolat 3am Hadome ğer biFaṭo duMamlo u luglozam dumat Işmux.',
'prefs-signature' => 'Imḍa',

# User preference: email validation using jQuery
'email-address-validity-valid' => 'uEmail-Adresayḍux m³adlo yo.',

# Groups
'group-user' => 'Hadome',
'group-all' => '(kulle)',

# Special:Log/newusers
'newuserlogpage' => 'User creation log',

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'Mşaḥlaf iFaṭaṭe',

# Recent changes
'nchanges' => '$1 {{PLURAL:$1|Şuḥlofo|Şuḥlofe}}',
'recentchanges' => 'Şuḥlofe ḥaroye',
'recentchanges-legend' => '3ayar daŞuḥlofe',
'recentchanges-summary' => 'biFaṭaṭe kibox ḥozat aŞuḥlofe ḥaroye.',
'recentchanges-feed-description' => 'biFaṭaṭe kibox ḥozat aŞuḥlofe ḥaroye.',
'recentchanges-label-newpage' => 'Faṭo ḥaṭto',
'recentchanges-label-minor' => 'This is a minor edit',
'recentchanges-label-bot' => 'uŞuḥlofano sim muBot.',
'recentchanges-label-unpatrolled' => 'This edit has not yet been patrolled',
'rcnote' => "Below {{PLURAL:$1|is '''1''' change|are the last '''$1''' changes}} in the last {{PLURAL:$2|day|'''$2''' days}}, as of $5, $4.",
'rcnotefrom' => 'Herke komaḥwın aŞuḥlofe ḥaroye men ""$2"" (hul buSowudo ""$1"").',
'rclistfrom' => 'Maḥway li Şuḥlofe ḥaṭe men $1',
'rcshowhideminor' => '$1 minor edits',
'rcshowhidebots' => '$1 bots',
'rcshowhideliu' => '$1 Hadome d3abiri',
'rcshowhideanons' => '$1 Hadomo nuxroyo',
'rcshowhidepatr' => '$1 patrolled edits',
'rcshowhidemine' => 'aMaṫwoṭayḍi ($1)',
'rclinks' => 'Maḥway li $1 aŞuḥlofe ḥaroye men meqım $2 Yawme hul u³do. <br />$3',
'diff' => 'Frişuṭo',
'hist' => 'Maktabzabno',
'hide' => 'Tlay',
'show' => 'Maḥway',
'minoreditletter' => 'm',
'newpageletter' => 'N',
'boteditletter' => 'b',
'rc-enhanced-expand' => 'Maḥway aŞelole',
'rc-enhanced-hide' => 'Tlay aŞelole',

# Recent changes linked
'recentchangeslinked' => 'Şuḥlofe bFaṭoṭe masre',
'recentchangeslinked-toolbox' => 'Şuḥlofe bFaṭoṭe masre',
'recentchangeslinked-title' => 'Şuḥlofe bFaṭoṭe dkıtne masre b$1',
'recentchangeslinked-summary' => "This is a list of changes made recently to pages linked from a specified page (or to members of a specified category).
Pages on [[Special:Watchlist|your watchlist]] are '''bold'''.",
'recentchangeslinked-page' => 'Işmo diFaṭo',
'recentchangeslinked-to' => 'Maḥway li Şuḥlofe dFaṭoṭe dkitne masre lerke.',

# Upload
'upload' => 'Mosaq Fayl',
'uploadlogpage' => 'Upload log',
'filedesc' => 'Sfiquṭo',
'uploadedimage' => 'mosaq "[[$1]]"',

'license' => 'Fsoso',
'license-header' => 'Fsoso',

# File description page
'file-anchor-link' => 'Fayl',
'filehist' => 'Maktabzabno duFayl',
'filehist-help' => 'Click on a date/time to view the file as it appeared at that time.',
'filehist-revert' => 'revert',
'filehist-current' => 'current',
'filehist-datetime' => 'Zabno',
'filehist-thumb' => 'Thumbnail',
'filehist-thumbtext' => 'Thumbnail for version as of $1',
'filehist-user' => 'Hadomo',
'filehist-dimensions' => 'Dimensions',
'filehist-comment' => 'Comment',
'imagelinks' => 'File usage',
'linkstoimage' => 'The following {{PLURAL:$1|page links|$1 pages link}} to this file:',
'nolinkstoimage' => 'There are no pages that link to this file.',
'sharedupload-desc-here' => 'This file is from $1 and may be used by other projects.
The description on its [$2 file description page] there is shown below.',

# Random page
'randompage' => 'Faṭo gedşonoyto',

# Statistics
'statistics' => 'Mardonwoṭo',

'brokenredirects-edit' => 'mşaḥlaf',
'brokenredirects-delete' => 'slag',

# Miscellaneous special pages
'nbytes' => '$1 {{PLURAL:$1|byte|bytes}}',
'nmembers' => '$1 {{PLURAL:$1|Hadomo|Hadome}}',
'prefixindex' => 'aFaṭoṭe kulle dkitte Prefiks',
'usercreated' => '{{GENDER:$3|kṭule}}  $1 b$2',
'newpages' => 'Faṭoṭe ḥaṭe',
'move' => 'Mtaxar',
'pager-newer-n' => '{{PLURAL:$1|1 ḥreno |$1 ḥrene}}',
'pager-older-n' => '{{PLURAL:$1|3atiqo1|3atiqe $1}}',

# Book sources
'booksources' => 'Kruxyo baNumarat duISBN',
'booksources-search-legend' => 'Krax Mabu³e me Kṭowe',
'booksources-go' => 'Zux',

# Special:Log
'log' => 'Logs',

# Special:AllPages
'allpages' => 'aFaṭaṭe kulle',
'alphaindexline' => '$1  l$2',
'allarticles' => 'aFaṭaṭe kulle',
'allpagesnext' => 'Ḥreto',
'allpagessubmit' => 'Zux',

# Special:Categories
'categories' => 'Sedre',

# Special:DeletedContributions
'deletedcontributions' => 'Maṫwoṭo slige',
'deletedcontributions-title' => 'Maṫwoṭo slige',
'sp-deletedcontributions-contribs' => 'Maṫwoṭo',

# Special:LinkSearch
'linksearch-ok' => 'Krax',
'linksearch-line' => '$1 masro yo b$2',

# Special:ListUsers
'listusers-submit' => 'Maḥway',

# Special:ListGroupRights
'listgrouprights-group' => 'Gudo',
'listgrouprights-rights' => 'Ḥaqat',
'listgrouprights-helppage' => 'Help: Ḥaqat diGudo',
'listgrouprights-members' => '(Lista daHadome)',

# Email user
'emailuser' => 'Kṭaw Email luHadomano.',
'emailusername' => 'Işme duHadomo:',
'emailfrom' => 'Men:',
'emailto' => 'Lwoṭ:',
'emailmessage' => 'Ṫebo:',

# Watchlist
'watchlist' => 'My watchlist',
'mywatchlist' => 'My watchlist',
'watchlistfor2' => 'L$1 $2',
'watch' => 'Watch',
'unwatch' => 'Unwatch',
'watchlist-details' => '{{PLURAL:$1|$1 page|$1 pages}} on your watchlist, not counting talk pages.',
'wlshowlast' => 'Maḥway li aŞuḥlofe dıtsimi meqım $1 Sa³ayat $2 Yawme $3',
'watchlist-options' => 'Watchlist options',

# Delete
'actioncomplete' => 'uDuboro kamıl',
'actionfailed' => 'Action failed',
'dellogpage' => 'Deletion log',

# Rollback
'rollbacklink' => 'rollback',

# Protect
'protectlogpage' => 'Protection log',
'protectedarticle' => 'mastar "[[$1]]"',

# Undelete
'undeletelink' => 'view/restore',
'undeleteviewlink' => 'ḥur',
'undelete-search-submit' => 'Krax',
'undelete-show-file-submit' => 'Eh',

# Namespace form on various pages
'namespace' => 'Dukṭo luIşmo',
'invert' => 'Invert selection',
'blanknamespace' => '(Rişoyto)',

# Contributions
'contributions' => 'Maṫwoṭo duHadomo:',
'contributions-title' => 'Maṫwoṭo d$1',
'mycontris' => 'aMaṫwoṭayḍi',
'contribsub2' => 'd$1 ($2)',
'uctop' => '(ḥaroyo)',
'month' => 'muYarḥo',
'year' => 'hul iŞato:',

'sp-contributions-newbies' => 'Bes maḥway Maṫwoṭo dHadome ḥaṭe',
'sp-contributions-blocklog' => 'Block log',
'sp-contributions-deleted' => 'Maṫwoṭo slige',
'sp-contributions-uploads' => 'Fayl masalqo',
'sp-contributions-logs' => 'logs',
'sp-contributions-talk' => 'Mamlo',
'sp-contributions-search' => 'Krax Maṫwoṭo',
'sp-contributions-username' => 'IP-Adres aw Işme duHadmomo:',
'sp-contributions-toponly' => 'Only show edits that are latest revisions',
'sp-contributions-submit' => 'Krax',

# What links here
'whatlinkshere' => 'Asirwoṭo biFaṭaṭe',
'whatlinkshere-title' => 'Faṭoṭe dkitte Asiruṭo 3am"$1"',
'whatlinkshere-page' => 'Faṭo',
'linkshere' => "aFaṭoṭani masre ne 3am '''[[:$1]]''':",
'nolinkshere' => "Layto Faṭoṭe dkitte Asiruṭo 3am '''[[:$1]]'''.",
'isredirect' => 'redirect page',
'istemplate' => 'transclusion',
'isimage' => 'Asiruṭo duFayl',
'whatlinkshere-prev' => '{{PLURAL:$1|meqımtır|$1 meqımtır}}',
'whatlinkshere-next' => '{{PLURAL:$1|ḥreno|$1 ḥrene}}',
'whatlinkshere-links' => '← Asirwoṭo',
'whatlinkshere-hideredirs' => '$1 redirects',
'whatlinkshere-hidetrans' => '$1 transclusions',
'whatlinkshere-hidelinks' => '$1 Asirwoṭo',
'whatlinkshere-hideimages' => '$1 Asiruṭo duFayl',
'whatlinkshere-filters' => 'Filtrat',

# Block/unblock
'ipboptions' => '2 Sa³ayat:2 hours,1 Yawmo:1 day,3 Yawme:3 days,1 Şabṭo:1 week,2 Şabe:2 weeks,1 Yarḥo:1 month,3 Yarḥe:3 months,6 Yarḥe :6 months,1 Şato:1 year,indefinite:infinite',
'ipblocklist' => 'Blocked users',
'ipblocklist-submit' => 'Krax',
'blocklink' => 'Maḥram',
'unblocklink' => 'unblock',
'change-blocklink' => 'change block',
'contribslink' => 'Maṫwoṭo',
'blocklogpage' => 'Block log',
'blocklogentry' => 'blocked [[$1]] with an expiry time of $2 $3',
'block-log-flags-nocreate' => 'account creation disabled',

# Move page
'movelogpage' => 'Move log',
'revertmove' => 'revert',

# Export
'export' => 'Mofaq iFaṭaṭe',

# Namespace 8 related
'allmessages' => 'Ṫebo duSistem dMEdiaWiki',
'allmessagesname' => 'Işmo',
'allmessagesdefault' => 'Syomo standard',
'allmessages-language' => 'Leşono',
'allmessages-filter-submit' => 'Zux',

# Thumbnails
'thumbnail-more' => 'Rabtır',
'thumbnail_error' => 'Error creating thumbnail: $1',

# Tooltip help for the actions
'tooltip-pt-userpage' => 'iFaṭaṭyḍox',
'tooltip-pt-mytalk' => 'iFaṭayḍux duDroşo',
'tooltip-pt-preferences' => 'a3ayaratayḍux',
'tooltip-pt-watchlist' => 'Lista dFaṭoṭe dkib³at mşaḥılfat',
'tooltip-pt-mycontris' => 'Lista daMaṫwoṭayḍox',
'tooltip-pt-login' => 'İnaqa demqaydat ruḥox ṫawo yo, elo letat mejbur',
'tooltip-pt-logout' => 'Nfoqo',
'tooltip-ca-talk' => 'Droşo 3al iFaṭo daḤbişoṭo',
'tooltip-ca-edit' => 'Kibux mşaḥılfat iFaṭaṭe, elo bo³o msta³mal uZra³lo duQontrol meqım demqaydat iFaṭo',
'tooltip-ca-addsection' => 'Bday Fusoqo ḥaṭo',
'tooltip-ca-viewsource' => 'This page is protected.
You can view its source',
'tooltip-ca-history' => 'Past revisions of this page',
'tooltip-ca-protect' => 'Mastar iFaṭaṭe',
'tooltip-ca-delete' => 'Slag iFaṭaṭe',
'tooltip-ca-move' => 'Mataxar iFaṭaṭe',
'tooltip-ca-watch' => 'Add this page to your watchlist',
'tooltip-ca-unwatch' => 'Remove this page from your watchlist',
'tooltip-search' => 'Krax{{SITENAME}}',
'tooltip-search-go' => 'Zux liFaṭo dkitla tam uIşmano.',
'tooltip-search-fulltext' => 'Krax uSyomano baFaṭoṭe',
'tooltip-p-logo' => 'Z³ar iFaṭo rişoyto',
'tooltip-n-mainpage' => 'Z³ar iFaṭo rişoyto',
'tooltip-n-mainpage-description' => 'Z³ar iFaṭo rişoyto',
'tooltip-n-portal' => '3al iProja; mın komisam u ayko u ayko ne a medone.',
'tooltip-n-currentevents' => 'Find background information on current events',
'tooltip-n-recentchanges' => 'Lista daŞuḥlofe ḥaroye kulle',
'tooltip-n-randompage' => 'Ftaḥ Faṭo gedşonoyto',
'tooltip-n-help' => 'Maḥway iFaṭo du3udrono',
'tooltip-t-whatlinkshere' => 'Lista daFaṭoṭe kulle dkitte Asiruṭo lerke',
'tooltip-t-recentchangeslinked' => 'Şuḥlofe ḥaroye bFaṭoṭe dkitte Asiruṭo lerke',
'tooltip-feed-atom' => 'Atom feed diFaṭaṭe',
'tooltip-t-contributions' => 'Lista daMaṫwoṭo duHadomano',
'tooltip-t-emailuser' => 'Mşadar Email luHadomano',
'tooltip-t-upload' => 'Mosaq aFayls',
'tooltip-t-specialpages' => 'Lista daFaṭoṭe dilonoye kulle.',
'tooltip-t-print' => 'Printable version of this page',
'tooltip-t-permalink' => 'Asiruṭo aminoyto liFaṭaṭe',
'tooltip-ca-nstab-main' => 'Maḥway iFaṭo daḤbişoṭo',
'tooltip-ca-nstab-user' => 'Maḥway iFaṭo duHadomo',
'tooltip-ca-nstab-special' => 'Haṭe Faṭo dilonoyto yo, laybux mşaḥalfatla',
'tooltip-ca-nstab-project' => 'Maḥway iFaṭo diProja',
'tooltip-ca-nstab-image' => 'Maḥway iFaṭo duFayl',
'tooltip-ca-nstab-template' => 'View the template',
'tooltip-ca-nstab-category' => 'Maḥway iFaṭo daSedre',
'tooltip-minoredit' => 'Mark this as a minor edit',
'tooltip-save' => 'Mqayad uŞuḥlofano',
'tooltip-preview' => 'Preview your changes, please use this before saving!',
'tooltip-diff' => 'Maḥway li aŞuḥlofe buSyomano',
'tooltip-compareselectedversions' => 'See the differences between the two selected revisions of this page',
'tooltip-watch' => 'Add this page to your watchlist',
'tooltip-rollback' => '"Rollback" reverts edit(s) to this page of the last contributor in one click',
'tooltip-undo' => '"Undo" reverts this edit and opens the edit form in preview mode. It allows adding a reason in the summary.',
'tooltip-summary' => 'Enter a short summary',

# Browsing diffs
'previousdiff' => '← Şuḥlofo 3atiqo',
'nextdiff' => 'Hiç lo mşaḥalfat →',

# Media information
'file-info-size' => '$1 × $2 pixels, file size: $3, MIME type: $4',
'file-nohires' => 'No higher resolution available.',
'svg-long-desc' => 'SCG Fayl, Rabuṭo $1 × $2 pixel, Rabuṭo duFayl: $3',
'show-big-image' => 'Tam faṥiḥ',

# Special:NewFiles
'ilsubmit' => 'Krax',

# Video information, used by Language::formatTimePeriod() to format lengths in the above messages
'seconds' => '{{PLURAL:$1|$1 Ṥaniye|$1 Ṥaniyat}}',
'ago' => 'meqım $1',

# Bad image list
'bad_image_list' => 'The format is as follows:

Only list items (lines starting with *) are considered.
The first link on a line must be a link to a bad file.
Any subsequent links on the same line are considered to be exceptions, i.e. pages where the file may occur inline.',

# Metadata
'metadata' => 'Metadata',
'metadata-help' => 'This file contains additional information, probably added from the digital camera or scanner used to create or digitize it.
If the file has been modified from its original state, some details may not fully reflect the modified file.',
'metadata-fields' => 'Image metadata fields listed in this message will be included on image page display when the metadata table is collapsed.
Others will be hidden by default.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

# Exif tags
'exif-writer' => 'Kaṭowo',
'exif-languagecode' => 'Leşono',
'exif-cameraownername' => 'uMoro diQamera',

# External editor support
'edit-externally' => 'Edit this file using an external application',
'edit-externally-help' => '(See the [//www.mediawiki.org/wiki/Manual:External_editors setup instructions] for more information)',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'kulle',
'namespacesall' => 'kulle',
'monthsall' => 'kulle',

# Watchlist editing tools
'watchlisttools-view' => 'View relevant changes',
'watchlisttools-edit' => 'View and edit watchlist',
'watchlisttools-raw' => 'Edit raw watchlist',

# Core parser functions
'duplicate-defaultsort' => '\'\'\'Warning:\'\'\' Default sort key "$2" overrides earlier default sort key "$1".',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Krax',

# Special:SpecialPages
'specialpages' => 'Faṭoṭe dilonoye',

# Special:BlankPage
'blankpage' => 'Faṭo xliṭo',

# External image whitelist
'external_image_whitelist' => ' #Leave this line exactly as it is<pre>
#Put regular expression fragments (just the part that goes between the //) below
#These will be matched with the URLs of external (hotlinked) images
#Those that match will be displayed as images, otherwise only a link to the image will be shown
#Lines beginning with # are treated as comments
#This is case-insensitive

#Put all regex fragments above this line. Leave this line exactly as it is</pre>',

# Special:Tags
'tag-filter' => '[[Special:Tags|Tag]] filter:',

# Special:ComparePages
'compare-page1' => 'Faṭo 1',
'compare-page2' => 'Faṭo 2',

# Database error messages
'dberr-problems' => 'Şubqono! iFaṭaṭe u3do kitla Qaṫre.',

# HTML forms
'htmlform-submit' => 'Mqayad',
'htmlform-selectorother-other' => 'Ḥrene',

# Feedback
'feedback-message' => 'Ṫebo:',
'feedback-cancel' => 'Mbaṫel',

# Search suggestions
'searchsuggest-search' => 'Kruxyo',

# API errors
'api-error-unknownerror' => 'Fawdo nuxroyo: $1',

# Durations
'duration-seconds' => '$1 {{PLURAL:$1|Ṥaniye|Ṥaniyat}}',
'duration-minutes' => '$1 {{PLURAL:$1|Qaṫınto|Qaṫınoṭo}}',
'duration-hours' => '$1 {{PLURAL:$1|Sa³aye|Sa³ayat}}',
'duration-days' => '$1 {{PLURAL:$1|Yawmo|Yawme}}',
'duration-weeks' => '$1 {{PLURAL:$1|Şabṭo|Şabe}}',
'duration-years' => '$1 {{PLURAL:$1|Şato|Şnaye}}',
'duration-decades' => '$1 {{PLURAL:$1|decade|decades}}',
'duration-centuries' => '$1 {{PLURAL:$1|Doro|Dore}}',

);
